import { Tab } from "@headlessui/react";
import React, { useEffect, useState } from "react";
import Modal from "../Modal/Modal";
import {
  useUpdateUserProfileMutation,
  useUserProfileQuery,
} from "../../app/features/userDashboard/apiSlice";
import CountrySelect from "../form/CountrySelect";
import useLanguage from "../../hooks/useLanguage";

function PersonalInfo() {
  const { data: info } = useUserProfileQuery();
  const [successUpdateInfoModal, setSuccessUpdateInfoModal] = useState(false);
  const [updateInfoModal, setUpdateInfoModal] = useState(false);
  const [updateInfo, setUpdateInfo] = useState({ ...info?.personInfo });
  const [updateUserProfile, { data, isLoading }] =
    useUpdateUserProfileMutation();
  // set info in state

  useEffect(() => {
    setUpdateInfo({ ...info?.personInfo });
  }, [info]);

  const handleSuccessModal = (status) => {
    if (status) {
      setUpdateInfoModal(false);
      setSuccessUpdateInfoModal(true);
    }
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    updateUserProfile({
      data: { ...updateInfo },
      setSuccess: handleSuccessModal,
    });
  };
  handleSubmit.bind(this);

  const handleChange = (e) => {
    setUpdateInfo((prev) => ({ ...prev, [e.target.name]: e.target.value }));
  };
  handleChange.bind(this);

  const handleCountrySelect = (id) => {
    setUpdateInfo((prev) => ({ ...prev, country_id: id }));
  };

  const handlePictureUpdate = (e) => {
    if (e.target.value !== "") {
      const imgReader = new FileReader();
      imgReader.onload = (event) => {
        setUpdateInfo((prev) => ({
          ...prev,
          previewImage: event.target.result,
        }));
      };
      imgReader.readAsDataURL(e.target.files[0]); //view
      setUpdateInfo((prev) => ({ ...prev, image: e.target.files[0] }));
    }
  };
  const language = useLanguage();
  return (
    <>
      <Tab.Panel>
        <div className="flex justify-between items-center mb-5">
          <div>
            <h3 className="text-2xl text-dark-300 font-bold notranslate">
              {language["Personal Info"]}
            </h3>
          </div>
          <div>
            <button
              onClick={() => setUpdateInfoModal(true)}
              className="bg-secondary transition hover:bg-secondary/80 py-2.5 px-5 rounded inline-flex justify-center items-center gap-1 text-dark-300 font-medium notranslate"
            >
              <svg
                width="19"
                height="20"
                viewBox="0 0 19 20"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
              >
                <path
                  d="M2.75 17.125H16.25M10.8383 4.70511C10.8383 4.70511 10.8383 5.99918 12.0643 7.29326C13.2902 8.58734 14.5162 8.58734 14.5162 8.58734M5.98972 14.7406L8.56425 14.3523C8.93562 14.2963 9.27977 14.1147 9.54503 13.8347L15.7422 7.29326C16.4193 6.57856 16.4193 5.4198 15.7422 4.7051L14.5162 3.41102C13.8391 2.69633 12.7414 2.69633 12.0643 3.41102L5.86712 9.95247C5.60186 10.2325 5.42979 10.5957 5.37674 10.9877L5.00894 13.7053C4.92721 14.3092 5.4176 14.8268 5.98972 14.7406Z"
                  stroke="#28303F"
                  strokeWidth="1.5"
                  strokeLinecap="round"
                />
              </svg>
              {language["Edit Info"]}
            </button>
          </div>
        </div>
        <div className="border border-primary-100 rounded-md p-5">
          <ul className="divide-y divide-primary-100">
            <li className="flex flex-wrap gap-10 items-center py-4 ">
              <h4 className="text-dark-200 font-bold text-lg notranslate">
                {language["Name"]}:
              </h4>
              <h4 className="text-dark-300 font-bold text-lg notranslate">
                {info?.personInfo?.name}
              </h4>
            </li>
            <li className="flex flex-wrap gap-10 items-center py-4">
              <h4 className="text-dark-200 font-bold text-lg notranslate">
                {language["Email"]}:
              </h4>
              <h4 className="text-dark-300 font-bold text-lg notranslate">
                {info?.personInfo?.email}
              </h4>
            </li>
            <li className="flex flex-wrap gap-10 items-center py-4">
              <h4 className="text-dark-200 font-bold text-lg notranslate">
                {language["Phone"]}:
              </h4>
              <h4 className="text-dark-300 font-bold text-lg notranslate">
                {info?.personInfo?.phone}
              </h4>
            </li>{" "}
            <li className="flex flex-wrap gap-10 items-center py-4">
              <h4 className="text-dark-200 font-bold text-lg notranslate">
                {language["Country"]}:{" "}
              </h4>
              <h4 className="text-dark-300 font-bold text-lg notranslate">
                {
                  info?.countries?.find(
                    (country) =>
                      country.id === Number(info.personInfo.country_id)
                  )?.name
                }
              </h4>
            </li>
            <li className="flex flex-wrap gap-10 items-center py-4">
              <h4 className="text-dark-200 font-bold text-lg notranslate">
                {language["Address"]}:
              </h4>
              <h4 className="text-dark-300 font-bold text-lg notranslate">
                {info?.personInfo?.address}
              </h4>
            </li>
            <li className="flex flex-wrap gap-10 items-center py-4">
              <h4 className="text-dark-200 font-bold text-lg notranslate">
                {language["Zip"]}:
              </h4>
              <h4 className="text-dark-300 font-bold text-lg notranslate">
                {info?.personInfo?.zip_code}
              </h4>
            </li>
          </ul>
        </div>
      </Tab.Panel>

      {/* update modal  */}
      <Modal isOpen={updateInfoModal} onClose={() => setUpdateInfoModal(false)}>
        <div className="bg-white relative rounded-2xl p-10 w-full">
          <button
            className="absolute top-4 right-4"
            onClick={() => setUpdateInfoModal(false)}
          >
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="36"
              height="36"
              viewBox="0 0 36 36"
              fill="none"
            >
              <path
                d="M22.2426 22.2426L13.7574 13.7574M13.7574 22.2426L22.2426 13.7574M18 33C26.2843 33 33 26.2843 33 18C33 9.71573 26.2843 3 18 3C9.71573 3 3 9.71573 3 18C3 26.2843 9.71573 33 18 33Z"
                stroke="#EB5757"
                strokeWidth="1.5"
                strokeLinecap="round"
              />
            </svg>
          </button>
          <div>
            <h3 className="text-4xl font-bold text-dark-300 mb-5 text-center w-full  sm:w-[700px] notranslate">
              {language["Create Account"]}
            </h3>
            <form onSubmit={handleSubmit}>
              <div className="grid  gap-5">
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Name"]}*
                  </label>
                  <input
                    type="text"
                    name="name"
                    value={updateInfo.name}
                    onChange={handleChange}
                    required
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="Shuvo Hasan"
                  />
                </div>{" "}
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Email"]}*
                  </label>
                  <input
                    type="text"
                    name="email"
                    value={updateInfo.email}
                    required
                    onChange={handleChange}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="demoemaill@gmail.com"
                  />
                </div>{" "}
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Phone"]}*
                  </label>
                  <input
                    type="text"
                    name="phone"
                    value={updateInfo.phone}
                    onChange={handleChange}
                    required
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="0398 2342 2342"
                  />
                </div>{" "}
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Country"]}*
                  </label>
                  <CountrySelect
                    name="country_id"
                    id="country"
                    handler={handleCountrySelect}
                    value={updateInfo?.country_id}
                    options={info?.countries}
                  />
                </div>{" "}
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Address"]}*
                  </label>
                  <input
                    type="text"
                    name="address"
                    value={updateInfo.address}
                    required
                    onChange={handleChange}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="Haydarabhad, Road 36"
                  />
                </div>{" "}
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Zip"]}*
                  </label>
                  <input
                    type="text"
                    name="zip_code"
                    value={updateInfo.zip_code}
                    required
                    onChange={handleChange}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="5148"
                  />
                </div>
                <div>
                  <label className="text-sm text-dark-200 block mb-2 notranslate">
                    {language["Update Profile Picture"]}*
                  </label>
                  <input
                    type="file"
                    name="image"
                    onChange={handlePictureUpdate}
                    className="w-full border border-primary-100 px-4 py-3 rounded-md focus:border-primary-100 focus:ring-primary-200"
                    placeholder="5148"
                  />
                </div>
                <div>
                  <button className="py-3.5 w-full px-8 text-center font-medium text-white rounded transition bg-primary-200 hover:bg-primary-200/80 notranslate">
                    {language["Update Info"]}
                  </button>
                </div>
              </div>
            </form>
          </div>
        </div>
      </Modal>

      {/* update success  */}
      {/* Success Info */}
      <Modal
        isOpen={successUpdateInfoModal}
        onClose={() => setSuccessUpdateInfoModal(false)}
      >
        <div className="bg-white relative rounded-2xl p-10 w-full">
          <button
            className="absolute top-4 right-4"
            onClick={() => setSuccessUpdateInfoModal(false)}
          >
            <svg
              xmlns="http://www.w3.org/2000/svg"
              width="36"
              height="36"
              viewBox="0 0 36 36"
              fill="none"
            >
              <path
                d="M22.2426 22.2426L13.7574 13.7574M13.7574 22.2426L22.2426 13.7574M18 33C26.2843 33 33 26.2843 33 18C33 9.71573 26.2843 3 18 3C9.71573 3 3 9.71573 3 18C3 26.2843 9.71573 33 18 33Z"
                stroke="#EB5757"
                strokeWidth="1.5"
                strokeLinecap="round"
              />
            </svg>
          </button>
          <div className="flex flex-col items-center justify-center gap-5">
            <svg
              width="260"
              height="249"
              viewBox="0 0 260 249"
              fill="none"
              xmlns="http://www.w3.org/2000/svg"
            >
              <path
                d="M131.139 248.344C199.851 248.344 255.472 192.726 255.472 124.172C255.472 55.5487 199.782 0 131.139 0C62.4965 0 6.80664 55.5487 6.80664 124.103C6.80664 192.726 62.4965 248.344 131.139 248.344Z"
                fill="url(#paint0_linear_491_10144)"
              />
              <path
                d="M28.7546 2.44425C29.2548 0.324572 32.2559 0.324572 32.7561 2.44425L34.4443 9.48907C34.6319 10.2372 35.1946 10.7983 35.9449 10.9853L43.0101 12.6686C45.1359 13.1673 45.1359 16.1598 43.0101 16.6586L35.9449 18.3419C35.1946 18.5289 34.6319 19.09 34.4443 19.8381L32.7561 26.8829C32.2559 29.0026 29.2548 29.0026 28.7546 26.8829L27.0664 19.8381C26.8789 19.09 26.3161 18.5289 25.5659 18.3419L18.5006 16.6586C16.3748 16.1598 16.3748 13.1673 18.5006 12.6686L25.5659 10.9853C26.3161 10.7983 26.8789 10.2372 27.0664 9.48907L28.7546 2.44425Z"
                fill="#8037A9"
              />
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M125.837 11.3001C127.915 11.3001 129.647 9.57073 129.647 7.49544C129.647 5.42014 127.915 3.69073 125.837 3.69073C123.759 3.69073 122.027 5.42014 122.027 7.49544C122.027 9.57073 123.69 11.3001 125.837 11.3001ZM125.837 14.1364C129.508 14.1364 132.487 11.1618 132.487 7.49544C132.487 3.82908 129.508 0.854492 125.837 0.854492C122.166 0.854492 119.188 3.82908 119.188 7.49544C119.188 11.1618 122.166 14.1364 125.837 14.1364Z"
                fill="#8037A9"
              />
              <path
                d="M245.697 116.361C245.35 114.977 246.666 113.663 248.052 114.078L257.541 116.776C258.927 117.191 259.411 118.92 258.372 119.958L251.307 126.806C250.268 127.844 248.537 127.36 248.121 125.907L245.697 116.361Z"
                fill="#8037A9"
              />
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M252.663 59.0042C254.741 59.0042 256.473 57.2748 256.473 55.1995C256.473 53.1242 254.741 51.3948 252.663 51.3948C250.585 51.3948 248.854 53.1242 248.854 55.1995C248.854 57.2748 250.585 59.0042 252.663 59.0042ZM252.663 61.8405C256.334 61.8405 259.313 58.8659 259.313 55.1995C259.313 51.5332 256.334 48.5586 252.663 48.5586C248.992 48.5586 246.014 51.5332 246.014 55.1995C246.014 58.8659 248.992 61.8405 252.663 61.8405Z"
                fill="#8037A9"
              />
              <path
                fill-rule="evenodd"
                clip-rule="evenodd"
                d="M6.64955 72.3919C8.72753 72.3919 10.4592 70.6625 10.4592 68.5872C10.4592 66.5119 8.72753 64.7825 6.64955 64.7825C4.57156 64.7825 2.83991 66.5119 2.83991 68.5872C2.83991 70.6625 4.5023 72.3919 6.64955 72.3919ZM6.64955 75.2282C10.3206 75.2282 13.2991 72.2536 13.2991 68.5872C13.2991 64.9209 10.3206 61.9463 6.64955 61.9463C2.97844 61.9463 0 64.9209 0 68.5872C0 72.2536 2.97844 75.2282 6.64955 75.2282Z"
                fill="#8037A9"
              />
              <path
                d="M177.193 85.9254V72.0093C177.193 69.2426 174.95 66.9995 172.184 66.9995C169.417 66.9995 167.174 69.2426 167.174 72.0093V89.2653H173.854C175.698 89.2653 177.193 87.7699 177.193 85.9254Z"
                fill="#8037A9"
              />
              <path
                d="M123.2 109.527H114.294C107.916 109.527 102.662 114.427 102.098 120.66H135.396C134.832 114.427 129.578 109.527 123.2 109.527Z"
                fill="#8037A9"
              />
              <path
                d="M118.746 102.847C123.05 102.847 126.539 99.3582 126.539 95.0543C126.539 90.7503 123.05 87.2612 118.746 87.2612C114.442 87.2612 110.953 90.7503 110.953 95.0543C110.953 99.3582 114.442 102.847 118.746 102.847Z"
                fill="#8037A9"
              />
              <path
                d="M148.351 156.352C147.244 159.778 151.594 162.289 154.007 159.618L162.811 149.873L152.388 143.855L148.351 156.352Z"
                fill="#8037A9"
              />
              <path
                d="M155.154 137.742L170.74 110.747L182.31 117.427L166.724 144.422L155.154 137.742Z"
                fill="#8037A9"
              />
              <path
                d="M187.658 94.8008C184.463 92.9563 180.378 94.0509 178.533 97.2458L174.08 104.959L185.65 111.639L190.103 103.926C191.948 100.731 190.853 96.6455 187.658 94.8008Z"
                fill="#8037A9"
              />
              <path
                d="M151.572 167.418H92.0275C90.183 167.418 88.6876 165.923 88.6876 164.078C88.6876 162.234 90.183 160.739 92.0275 160.739H142.062C141.335 158.701 141.296 156.46 141.994 154.299L147.004 138.794C147.148 138.346 147.34 137.915 147.575 137.508L160.495 115.13V72.0093C160.495 70.2174 160.901 68.5189 161.625 66.9995H87.0177C81.4928 66.9995 76.998 71.4943 76.998 77.0191V177.661C76.998 179.505 78.4934 181 80.3379 181H160.495V162.4L158.963 164.096C157.028 166.238 154.403 167.418 151.572 167.418ZM95.3673 121.773C95.3673 113.74 100.401 106.864 107.478 104.122C105.476 101.639 104.274 98.4851 104.274 95.0544C104.274 87.0741 110.766 80.5817 118.746 80.5817C126.727 80.5817 133.219 87.0741 133.219 95.0544C133.219 98.4851 132.017 101.639 130.015 104.122C137.092 106.864 142.126 113.74 142.126 121.773V124C142.126 125.844 140.63 127.34 138.786 127.34H98.7072C96.8627 127.34 95.3673 125.844 95.3673 124V121.773ZM92.0275 134.02H134.333C136.177 134.02 137.672 135.515 137.672 137.359C137.672 139.204 136.177 140.699 134.333 140.699H92.0275C90.183 140.699 88.6876 139.204 88.6876 137.359C88.6876 135.515 90.183 134.02 92.0275 134.02ZM92.0275 147.379H134.333C136.177 147.379 137.672 148.874 137.672 150.719C137.672 152.563 136.177 154.059 134.333 154.059H92.0275C90.183 154.059 88.6876 152.563 88.6876 150.719C88.6876 148.874 90.183 147.379 92.0275 147.379Z"
                fill="#8037A9"
              />
              <defs>
                <linearGradient
                  id="paint0_linear_491_10144"
                  x1="130.178"
                  y1="-40.5135"
                  x2="132.718"
                  y2="395.637"
                  gradientUnits="userSpaceOnUse"
                >
                  <stop stop-color="white" stopOpacity="0" />
                  <stop offset="1" stop-color="#8037A9" />
                </linearGradient>
              </defs>
            </svg>
            <h3 className="text-3xl font-bold text-dark-300 text-center notranslate">
              {language["Personal info update Successfully"]}
            </h3>
            <button
              onClick={() => setSuccessUpdateInfoModal(false)}
              className="py-3.5 w-full px-8 text-center font-medium text-white rounded transition bg-primary-200 hover:bg-primary-200/80 notranslate"
            >
              {language["Thanks"]}
            </button>
          </div>
        </div>
      </Modal>
    </>
  );
}

export default PersonalInfo;
